@@ -22,15 +22,14 @@ import java.util.Enumeration;
 import java.util.Locale;
 import java.util.ResourceBundle;
 
-import junit.framework.Assert;
-
+import org.junit.Assert;
 import org.junit.Test;
 
 public class LocalizedFormatsTest {
 
     @Test
     public void testMessageNumber() {
-        Assert.assertEquals(312, LocalizedFormats.values().length);
+        Assert.assertEquals(322, LocalizedFormats.values().length);
     }
 
     @Test
